;+
;
;
;                      Tropospheric Emission
;                          Spectrometer
;                             (TES)
;
;                         Copyright 2005,
;              California Institute of Technology.
;                       ALL RIGHTS RESERVED.
;           U.S. Government Sponsorship acknowledged.
;
;
;
; read_l1b_hdf_eng
;
; PURPOSE:
;	Read TES L1B Engineering data from L1B HDF product files
;	(version F02, F03)
;
; CALL:
;	 read_l1b_hdf_eng,file,filter,data,status=status
;
; INPUTS:
;	file = name of file to be read (string)
; 	filter = name of filter subset to read (string)
;
; OUTPUTS:
;	data = L1B engineering data from L1A diagnostic file, an
;		array (number of elements equals number of
;		observations) of structures.  The structures have
;		the following fields:
;
; 		SCAN            	BYTE         
; 		SEQUENCE        	INT              
; 		TIME_OF_OBSERVATION  	DOUBLE      
;    		FILTER_IDENTIFICATION   STRING
;    		ADC_ENABLED     	INT     
;    		ELECT_FILTER    	FLOAT          
;    		FRINGE_CLOCK_DIVISOR	INT        
;    		AT_INDEX       		BYTE 
;    		FILTER_WHEEL_INDEX	INT 
;    		SIGNAL_CHAIN_GAIN	FLOAT
;    		DETECTOR_TEMP   	FLOAT 
;    		OBSERVATION_TYPE	INT   
;    		ICS_SCAN_DIRECTION	STRING
;    		BLACKBODY_WALL_TEMP__1	FLOAT    
;    		BLACKBODY_WALL_TEMP__2	FLOAT 
;    		COLD_REFERENCE_PLATE_TEMP__1	FLOAT
;    		COLD_REFERENCE_PLATE_TEMP__2	FLOAT
;    		BEAMSPLITTER_TEMP__1	FLOAT
;    		BEAMSPLITTER_TEMP__2	FLOAT
;    		FOREOPTICS_TEMP 	FLOAT       
;    		M1_MIRROR_TEMP  	FLOAT 
;    		M2_MIRROR_TEMP  	FLOAT   
;    		CALIBRATION_SS_RESISTOR_1	FLOAT
;    		CALIBRATION_SS_RESISTOR_2	FLOAT
;    		OSE_RESISTOR_1  	FLOAT
;    		OSE_RESISTOR_2  	FLOAT
;
;	Output data is undefined upon an error condition
;
; KEYWORD OUTPUT:
;	status = 0 for success
;		 1 if file does not exist
;		 2 the file name does not have F02_01 in name
;		 3 the file is not HDF 5
; 
; ORIGINAL AUTHOR:
;	Brendan Fisher, JPL, 07/2005
;
; UPDATE HISTORY:
;
;-
pro read_l1b_hdf_eng,file,filter,data,status=status

if n_params() ne 3 then begin
    print,'Usage:'
    print,'read_l1b_hdf_eng,file,filter,data,status=status'
    return
endif


status=0

; check for file existence
ff = file_search(file,count=count)
if count eq 0 then begin
    print,'Cannot find file:'
    print,file
    status = 1
    return
endif
pos2 = strpos(file,'_F02_')
pos3 = strpos(file,'_F03_')
if pos2 ne -1 then version = 2
if pos3 ne -1 then version = 3
pos=0
if pos eq -1 then begin
    print,'Expected version _F02_ or _F03_ in file name not found.'
    print,file
    status = 2
    return
endif
; check to see if file is an HDF5 
if not h5f_is_hdf5(file) then begin
    print,'File is not HDF 5:'
    print,file
    status=3
    return
endif

fid = h5f_open(file)

groupid = h5g_open(fid,'Filter'+strupcase(filter))

engid = h5d_open(groupid,'Engineering')

data = h5d_read(engid)

h5d_close,engid


h5g_close, groupid
h5f_close,fid


return

end
