;+
;
;
;                      Tropospheric Emission
;                          Spectrometer
;                             (TES)
;
;                         Copyright 2005,
;              California Institute of Technology.
;                       ALL RIGHTS RESERVED.
;           U.S. Government Sponsorship acknowledged.
;
;
;
; read_l1b_hdf_tesmeta
;
; PURPOSE:
; 	Read TES L1B HDF file for the L1B TES metadata
;
; CALL:
; 	read_l1b_hdf_tesmeta,file,data,status=status
;
; INPUTS:
;	file = name of file to be read (string)
;
; KEYWORD INPUT:
;	read_ph = if set, read production history.  If not set, the
;		production history will be a null string
;
; OUTPUTS:
;	data = metadata information as a structure
;	with the following fields:
;	       productionhistory (string)
;	       instrumentname (string)
;	       processlevel (string)
;	       TAI93at0zOfGranule (double)
;	       GlobalSurveyNumber (long64)
;	       granulemonth (byte)
;	       granuleday (byte)
;	       granuleyear (integer)
;	       surveymode (string)
;	       pgeversion (string)
;	       command_seq_id (long) (V3) (zero for V2)
;
;
; KEYWORD OUTPUT:
;	status = 0 for success
;		 1 if file does not exist
;		 2 the file name does not have F02_01 in name
;		 3 the file is not HDF 5
; 
; ORIGINAL AUTHOR:
;	Brendan Fisher, JPL, 07/2005
;
; UPDATE HISTORY:
;
;-
pro read_l1b_hdf_tesmeta,file,data,status=status,read_ph=read_ph

if n_params() ne 2 then begin
    print,'Usage:'
    print,'read_l1b_hdf_tesmeta,file,metadata,status=status'
    return
endif
status=0
if n_elements(read_ph) eq 0 then read_ph = 0

; check for file existence
ff = file_search(file,count=count)
if count eq 0 then begin
    print,'Cannot find file:'
    print,file
    status = 1
    return
endif
; check version
pos2 = strpos(file,'_F02_')
pos3 = strpos(file,'_F03_')
if pos2 ne -1 then version = 2
if pos3 ne -1 then version = 3
pos=0
if pos eq -1 then begin
    print,'Expected version _F02_ or _F03_ in file name not found.'
    print,file
    status = 2
    return
endif
; check to see if file is an HDF5 
if not h5f_is_hdf5(file) then begin
    print,'File is not HDF 5:'
    print,file
    status=3
    return
endif


fid = h5f_open(file)


subid = h5g_open(fid,'TESMetadataGroup')

data = { $
       productionhistory : '', $
       instrumentname : '', $
       processlevel : '', $
       TAI93at0zOfGranule : 0.0d, $
       GlobalSurveyNumber : 0ll, $
       granulemonth : 0b, $
       granuleday : 0b, $
       granuleyear : 0, $
       surveymode : '', $
       pgeversion : '', $
       command_seq_id : 0l  }

if read_ph ne 0 then begin
    id = h5d_open(subid,'ProductionHistory')
    data.productionhistory = h5d_read(id)
    h5d_close,id
endif else ProductionHistory = ''

id = h5a_open_name(subid,'InstrumentName')
data.instrumentname = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'ProcessLevel')
data.processlevel = h5a_read(id)
h5a_close,id

if version eq 2 then begin
    id = h5a_open_name(subid,'TAI93AtOzOfGranule')
    TAI93AtOzOfGranule = h5a_read(id)
    h5a_close,id
endif
if version eq 3 then begin
    id = h5a_open_name(subid,'TAI93At0zOfGranule')
    TAI93At0zOfGranule = h5a_read(id)
    h5a_close,id
endif    

id = h5a_open_name(subid,'GlobalSurveyNumber')
data.GlobalSurveyNumber = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'GranuleMonth')
data.granulemonth = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'GranuleDay')
data.granuleday = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'GranuleYear')
data.granuleyear = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'SurveyMode')
data.surveymode = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'PGEVersion')
data.pgeversion = h5a_read(id)
h5a_close,id

if version eq 3 then begin
    id = h5a_open_name(subid,'Command_Seq_ID')
    data.command_seq_id = h5a_read(id)
    h5a_close,id
endif else data.command_seq_id = 0



h5g_close,subid
h5f_close,fid


return

end
